@@ -1,9 +1,10 @@
 package App::findeps;
-use 5.012_001;
+
+use 5.012005;
 use strict;
 use warnings;
 
-our $VERSION = "0.03";
+our $VERSION = "0.04";
 
 use Carp qw(carp croak);
 use ExtUtils::Installed;
@@ -60,7 +61,7 @@ sub scan_line {
     my @names = ();
     return if /eval/;
     if (/use\s+(?:base|parent)\s+qw[\("'{](?:\s*([^'"\);]+))\s*[\)"'}]/) {
-        push @names, split / /, $1;
+        push @names, split /\s+/, $1;
     } elsif (/(?:use(?:\s+base|\s+parent|\s+autouse)?|require)\s+(['"]?)([^'"\s;]+)\1/o) {
         push @names, $2;
     }
@@ -68,6 +69,7 @@ sub scan_line {
         next unless length $name;
         next if exists $pairs->{$name};
         next if $name =~ /^5/;
+        next if $name eq 'Plack::Builder';
         next if first { $name eq $_ } @pragmas;
         $pairs->{$name} = get_version($name);
     }
@@ -106,6 +108,12 @@ Via the command-line program L<findeps>;
 
 App::findeps is a base module for executing L<findeps>
 
+=head1 TODO
+
+L<Plack::Builder> import modules C<Plack::Middleware::*> with C<enable>
+but it's not supported yet.
+
+
 =head1 SEE ALSO
 
 L<findeps>
